<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>About</name>
    <message>
        <location filename="../about.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../about.ui" line="47"/>
        <source>Packet Sender</source>
        <translation>Packet Sender</translation>
    </message>
    <message>
        <location filename="../about.ui" line="136"/>
        <source>Written by Dan Nagle and published by NagleCode, LLC</source>
        <translation>Geschrieben von Dan Nagle und veröffentlicht von NagleCode, LLC</translation>
    </message>
    <message>
        <location filename="../about.ui" line="165"/>
        <source>TextLabel</source>
        <translation>TextEtikett</translation>
    </message>
    <message>
        <location filename="../about.ui" line="185"/>
        <source>PacketSender.com</source>
        <translation>PacketSender.com</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="26"/>
        <source>
Commit Hash: </source>
        <translation>
Hash eintragen: </translation>
    </message>
    <message>
        <location filename="../about.cpp" line="31"/>
        <source>About Packet Sender</source>
        <translation>Über Paket Sender</translation>
    </message>
</context>
<context>
    <name>BruceThePoodle</name>
    <message>
        <location filename="../brucethepoodle.ui" line="26"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../brucethepoodle.cpp" line="29"/>
        <source>Bruce The Poodle!</source>
        <translation>Bruce der Pudel!</translation>
    </message>
</context>
<context>
    <name>CloudUI</name>
    <message>
        <location filename="../cloudui.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="28"/>
        <source>Account</source>
        <translation>Konto</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="49"/>
        <source>Packet Sender Cloud</source>
        <translation>Paket Sender Cloud</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="73"/>
        <source>Username</source>
        <translation>Benutzername</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="91"/>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="112"/>
        <source>Confirm Password</source>
        <translation>Bestätigen Sie das Passwort</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="131"/>
        <source>Remember Login</source>
        <translation>Anmeldung merken</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="140"/>
        <location filename="../cloudui.cpp" line="466"/>
        <source>Login</source>
        <translation>Einloggen</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="150"/>
        <location filename="../cloudui.cpp" line="465"/>
        <source>Create a new account.</source>
        <translation>Erstellen ein neues Konto.</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="187"/>
        <source>Privacy</source>
        <translation>Datenschutz</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="194"/>
        <source>Terms</source>
        <translation>Bedingungen</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="214"/>
        <source>cloud.packetsender.com/help</source>
        <translation>cloud.packetsender.com/help</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="228"/>
        <source>Import</source>
        <translation>Importieren</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="239"/>
        <source>Import From URL</source>
        <translation>Aus URL importieren</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="248"/>
        <location filename="../cloudui.ui" line="372"/>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="268"/>
        <source>View URL</source>
        <translation>URL ansehen</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="283"/>
        <source>Delete Packet Set</source>
        <translation>Paketsatz löschen</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="290"/>
        <source>Import Packet Set</source>
        <translation>Paketsatz importieren</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="307"/>
        <source>Save / Share</source>
        <translation>Speichern / Teilen</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="313"/>
        <source>You are sharing.</source>
        <translation>Du teilst.</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="322"/>
        <source>Packet Set Name</source>
        <translation>Name des Paketsatzes</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="336"/>
        <source>Public Path</source>
        <translation>Öffentlicher Pfad</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="359"/>
        <source>Make Public</source>
        <translation>Öffentlich machen</translation>
    </message>
    <message>
        <location filename="../cloudui.ui" line="401"/>
        <source>Save to Packet Sender Cloud</source>
        <translation>In der Paket Sender Cloud speichern</translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="83"/>
        <source>Cloud</source>
        <translation>Cloud&gt;</translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="100"/>
        <source>Saving </source>
        <translation>Sparen </translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="100"/>
        <source> packet set to cloud</source>
        <translation> paket auf Cloud gesetzt</translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="470"/>
        <source>Login instead.</source>
        <translation>Loggen Sie sich stattdessen ein.</translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="471"/>
        <source>Sign-up</source>
        <translation>Melde dich an</translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="528"/>
        <source>Delete Set</source>
        <translation>Satz löschen</translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="533"/>
        <source>Delete the set </source>
        <translation>Lösche das Set </translation>
    </message>
    <message>
        <location filename="../cloudui.cpp" line="533"/>
        <source> from cloud?</source>
        <translation>aus der Cloud?</translation>
    </message>
</context>
<context>
    <name>IrisAndMarigold</name>
    <message>
        <location filename="../irisandmarigold.ui" line="26"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
</context>
<context>
    <name>LanguageChooser</name>
    <message>
        <location filename="../languagechooser.ui" line="14"/>
        <source>Choose Language</source>
        <translation>Sprache wählen</translation>
    </message>
    <message>
        <location filename="../languagechooser.ui" line="46"/>
        <source>Español</source>
        <translation>Español</translation>
    </message>
    <message>
        <location filename="../languagechooser.ui" line="79"/>
        <source>English</source>
        <translation>English</translation>
    </message>
    <message>
        <location filename="../languagechooser.ui" line="115"/>
        <source>Deutsch</source>
        <translation>Deutsch</translation>
    </message>
    <message>
        <location filename="../languagechooser.ui" line="151"/>
        <source>Français</source>
        <translation>Français</translation>
    </message>
    <message>
        <location filename="../languagechooser.ui" line="187"/>
        <source>Italiano</source>
        <translation>Italiano</translation>
    </message>
    <message>
        <location filename="../languagechooser.ui" line="206"/>
        <source>OK / Aceptar</source>
        <translation>OK / Aceptar</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>MainWindow</source>
        <translation>MainWindow</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="35"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="48"/>
        <source>Packet Name</source>
        <translation>Name des Pakets</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>Request</source>
        <translation>Anfrage</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="79"/>
        <source>URL path</source>
        <translation>URL Pfad</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <source>ASCII</source>
        <translation>ASCII</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="100"/>
        <source>Generate Data</source>
        <translation>Daten generieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="107"/>
        <source>ASCII representation</source>
        <translation>ASCII Darstellung</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="117"/>
        <source>Load File</source>
        <translation>Datei laden</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="128"/>
        <source>HEX</source>
        <translation>HEX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="135"/>
        <source>HEX representation</source>
        <translation>HEX Darstellung</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="151"/>
        <source>Address</source>
        <translation>Adresse</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <source>IPv4, IPv6, DNS Lookup</source>
        <translation>IPv4, IPv6, DNS Suche</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="184"/>
        <source>1 to 65535</source>
        <translation>1 bis 65535</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="194"/>
        <source>Resend Delay</source>
        <translation>Verzögerung erneut senden</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="207"/>
        <source>0.0/blank off</source>
        <translation>0.0/blank aus</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="230"/>
        <source>TCP</source>
        <translation>TCP</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="239"/>
        <source>UDP</source>
        <translation>UDP</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>SSL</source>
        <translation>SSL</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="257"/>
        <source>HTTP Get</source>
        <translation>HTTP Get</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="266"/>
        <source>HTTP Post</source>
        <translation>HTTP Post</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="275"/>
        <source>HTTPS Get</source>
        <translation>HTTPS Get</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="284"/>
        <source>HTTPS Post</source>
        <translation>HTTPS Post</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="296"/>
        <location filename="../mainwindow.cpp" line="1074"/>
        <location filename="../mainwindow.cpp" line="1732"/>
        <source>Send</source>
        <translation>Senden</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="303"/>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="332"/>
        <source>Search Saved Packets...</source>
        <translation>Gespeicherte Pakete durchsuchen...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="360"/>
        <source>Generate Panel!</source>
        <translation>Panel generieren!</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="383"/>
        <source>Delete Saved Packet</source>
        <translation>Gespeichertes Paket löschen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="390"/>
        <source>Persistent TCP</source>
        <translation>Persistentes TCP</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="427"/>
        <source>Clear Log</source>
        <translation>Log löschen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="447"/>
        <source>Log Traffic</source>
        <translation>Log Verkehr</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="457"/>
        <source>Save Log</source>
        <translation>Log speichern</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="464"/>
        <source>Save Traffic Packet</source>
        <translation>Verkehrspaket speichern</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="471"/>
        <source>Copy to Clipboard</source>
        <translation>In die Zwischenablage kopieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="519"/>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="528"/>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="539"/>
        <source>&amp;Tools</source>
        <translation>&amp;Werkzeuge</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="548"/>
        <source>&amp;Multicast</source>
        <translation>&amp;Multicast</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="554"/>
        <source>Panels</source>
        <translation>Paneele</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="572"/>
        <source>E&amp;xit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="581"/>
        <source>&amp;Settings</source>
        <translation>&amp;Einstellungen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="590"/>
        <source>&amp;About</source>
        <translation>&amp;Über</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="599"/>
        <source>&amp;Import Database</source>
        <translation>&amp;Datenbank importieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="608"/>
        <source>&amp;Export Database</source>
        <translation>&amp;Datenbank exportieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="613"/>
        <source>Persistent Connection</source>
        <translation>persistente Verbindung</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="622"/>
        <source>&amp;Subnet Calculator</source>
        <translation>&amp;Subnetz Rechner</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="631"/>
        <source>D&amp;onate (Thank You!)</source>
        <translation>&amp;spenden Sie (Danke!)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="636"/>
        <source>Documentation</source>
        <translation>Dokumentation</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="645"/>
        <source>&amp;Documentation</source>
        <translation>&amp;Dokumentation</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="650"/>
        <source>Export To Cloud</source>
        <translation>In die Cloud exportieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="659"/>
        <source>&amp;Cloud Save and Share</source>
        <translation>&amp;Cloud Speichern und Teilen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="668"/>
        <source>&amp;Join/Leave IPv4</source>
        <translation>&amp;IPv4 beitreten/verlassen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="677"/>
        <source>Android App</source>
        <translation>Android App</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="686"/>
        <source>iOS App</source>
        <translation>iOS App</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="695"/>
        <source>Follow on Twitter</source>
        <translation>Folge uns auf Twitter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="704"/>
        <source>Connect on LinkedIn</source>
        <translation>Verbinde dich auf LinkedIn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="713"/>
        <source>Intense &amp;Traffic Generator</source>
        <translation>Intensiver &amp;Verkehrsgenerator</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="722"/>
        <source>Forums</source>
        <translation>Foren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="727"/>
        <source>Load Starter Panel</source>
        <translation>Laststarter Panel</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="732"/>
        <source>Empty Panel Project</source>
        <translation>Leeres Panel Projek</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="741"/>
        <source>Wake-On-LAN / Magic Packet</source>
        <translation>Wake-On-LAN</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="594"/>
        <location filename="../mainwindow.cpp" line="622"/>
        <source>Updates.</source>
        <translation>Aktualisierungen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="598"/>
        <source>There is a new Packet Sender available.

Download?</source>
        <translation>Es ist ein neuer Packet Sender verfügbar


Herunterladen?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="626"/>
        <source>Let Packet Sender check for updates weekly?</source>
        <translation>Packet Sender wöchentlich nach Updates suchen lassen?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="670"/>
        <source>Packet Sender Updated!</source>
        <translation>Paket-Absender aktualisiert</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="674"/>
        <source>Updated to </source>
        <translation>Aktualisiert auf </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="674"/>
        <source>!

Would you like to read the release notes?</source>
        <translation>!

Möchten Sie die Versionshinweise lesen?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="735"/>
        <source>Clear Log </source>
        <translation>Log löschen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="760"/>
        <location filename="../mainwindow.cpp" line="782"/>
        <location filename="../mainwindow.cpp" line="803"/>
        <source> Ports</source>
        <translation>Häfen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="766"/>
        <source>UDP Server Disabled</source>
        <translation>UDP Server Deaktiviert</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="788"/>
        <source>SSL Server Disabled</source>
        <translation>SSL Server Deaktiviert</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="810"/>
        <source>TCP Server Disabled</source>
        <translation>TCP Server Deaktiviert</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1030"/>
        <location filename="../mainwindow.cpp" line="1271"/>
        <source>Multicast detected.</source>
        <translation>Multicast erkannt.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1034"/>
        <source>Do you wish to join the multicast group?</source>
        <translation>Möchten Sie der Multicast-Gruppe beitreten?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1050"/>
        <location filename="../mainwindow.cpp" line="1293"/>
        <source>Broadcast with responses!</source>
        <translation>Sendung mit Antworten!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1054"/>
        <location filename="../mainwindow.cpp" line="1297"/>
        <source>You are sending a broadcast packet with responses enabled.

This could cause traffic flooding. Continue?</source>
        <translation>Sie senden ein Broadcast-Paket mit aktivierten Antworten.

Dies könnte zu Verkehrsüberflutungen führen.Fortfahren?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="234"/>
        <location filename="../mainwindow.cpp" line="1068"/>
        <location filename="../mainwindow.cpp" line="1333"/>
        <location filename="../mainwindow.cpp" line="1939"/>
        <source>Resending</source>
        <translation>Erneut senden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1074"/>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1101"/>
        <source>Name cannot be blank.</source>
        <translation>Der Name darf nicht leer sein.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1105"/>
        <source>Name is empty.</source>
        <translation>Der Name ist leer.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1155"/>
        <source>This computer does not support SSL.

Expected SSL:</source>
        <translation>Dieser Computer unterstützt kein SSL.

Erwartetes SSL:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1159"/>
        <source>No SSL Library.</source>
        <translation>Keine SSL-Bibliothek.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1212"/>
        <source>Address cannot be blank.</source>
        <translation>Die Adresse darf nicht leer sein.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1216"/>
        <source>Address is empty.</source>
        <translation>Die Adresse ist leer.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1227"/>
        <source>Port cannot be blank/zero.</source>
        <translation>Port kann nicht leer/null sein.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1231"/>
        <source>Port is zero.</source>
        <translation>Port ist Null.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1245"/>
        <source>IPv6?</source>
        <translation>IPv6?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1249"/>
        <source>Enable IPv6 support?</source>
        <translation>IPv6-Unterstützung aktivieren?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1275"/>
        <source>Join UDP multicast group?</source>
        <translation>UDP-Multicast-Gruppe beitreten?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1313"/>
        <source>Resend TCP with persistent connections!</source>
        <translation>TCP mit persistenten Verbindungen neu senden!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1317"/>
        <source>You are resending a TCP packet with persistent connections. The UI could spawn numerous windows! 

Uncheck persistent connection? (Recommended)</source>
        <translation>Sie senden ein TCP-Paket mit persistenten Verbindungen erneut. Die Benutzeroberfläche könnte zahlreiche Fenster erzeugen!

Persistente Verbindung deaktivieren? (Empfohlen)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1352"/>
        <location filename="../mainwindow.cpp" line="2002"/>
        <source>No packets selected.</source>
        <translation>Keine Pakete ausgewählt.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1356"/>
        <source>Select a packet.</source>
        <translation>Wählen Sie ein Paket aus.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1395"/>
        <source>Invalid Address / DNS failed</source>
        <translation>Ungültige Adresse / DNS fehlgeschlagen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1418"/>
        <source>Invalid Port</source>
        <translation>Ungültiger port</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1862"/>
        <source>Clear Log (0)</source>
        <translation>Log löschen (0)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1881"/>
        <source>Save Packet</source>
        <translation>Packet speichern</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1882"/>
        <source>Packet name:</source>
        <translation>Name des Pakets:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2006"/>
        <source>Clipboard unchanged.</source>
        <translation>Zwischenablage unverändert.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2067"/>
        <source>Save Traffic Log</source>
        <translation>Verkehrslog speichern</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2068"/>
        <source>log (*.log)</source>
        <translation>log (*.log)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2086"/>
        <source>TIME</source>
        <translation>ZEIT</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2086"/>
        <source>From IP</source>
        <translation>Von IP</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2086"/>
        <source>From Port</source>
        <translation>Von Port</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2086"/>
        <source>To IP</source>
        <translation>Zu IP</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2087"/>
        <source>To Port</source>
        <translation>Zum Port</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2087"/>
        <source>Method</source>
        <translation>Methode</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2087"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2262"/>
        <source>Import JSON</source>
        <translation>JSON importieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2264"/>
        <location filename="../mainwindow.cpp" line="2331"/>
        <source>JSON db (*.json)</source>
        <translation>JSON db (*.json)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2288"/>
        <location filename="../mainwindow.cpp" line="2425"/>
        <source>Found </source>
        <translation>Gefunden</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2288"/>
        <location filename="../mainwindow.cpp" line="2425"/>
        <source> packets!</source>
        <translation> Pakete!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2292"/>
        <location filename="../mainwindow.cpp" line="2429"/>
        <source>Import </source>
        <translation>Importieren </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2292"/>
        <location filename="../mainwindow.cpp" line="2429"/>
        <source> packets?

Packet Sender will overwrite packets with the same name.</source>
        <translation> pakete?

Paketsender überschreibt Pakete mit demselben Namen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2295"/>
        <location filename="../mainwindow.cpp" line="2316"/>
        <location filename="../mainwindow.cpp" line="2432"/>
        <location filename="../mainwindow.cpp" line="2453"/>
        <source>Import Cancelled</source>
        <translation>Import abgebrochen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2303"/>
        <source>Import Finished</source>
        <translation>Importiert Abgeschlossen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2309"/>
        <location filename="../mainwindow.cpp" line="2446"/>
        <source>Not a database</source>
        <translation>Nicht eine Datenbank</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2313"/>
        <location filename="../mainwindow.cpp" line="2450"/>
        <source>Found no packets in this file. It may not be a Packet Sender export</source>
        <translation>Es wurden keine Pakete in dieser Datei gefunden. Es handelt sich möglicherweise nicht um einen Paketsender exportieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2330"/>
        <source>Save JSON</source>
        <translation>JSON speichern</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2352"/>
        <location filename="../mainwindow.cpp" line="2485"/>
        <source>Export: </source>
        <translation>Exportieren:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2356"/>
        <source>Could not save</source>
        <translation>Konnte nicht speichern</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2360"/>
        <source>Could not open </source>
        <translation>Konnte nicht geöffnet werden </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2406"/>
        <location filename="../mainwindow.cpp" line="2531"/>
        <source>Import File</source>
        <translation>Datei importieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2408"/>
        <location filename="../mainwindow.cpp" line="2463"/>
        <source>INI db (*.ini)</source>
        <translation>INI db (*.ini)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2462"/>
        <source>Save File</source>
        <translation>Datei speichern</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2533"/>
        <source>*.*</source>
        <translation>*.*</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2557"/>
        <source>Max size exceeded!</source>
        <translation>Die maximale Größe wurde überschritten!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2561"/>
        <source>The HEX field supports up to 10,922 bytes. The data has been truncated.</source>
        <translation>Das HEX-Feld unterstützt bis zu 10.922 Bytes. Die Daten wurden abgeschnitten.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2567"/>
        <source>Loading </source>
        <translation>Wird geladen </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2567"/>
        <source> bytes</source>
        <translation> bytes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2801"/>
        <source>Invalid MAC Address.</source>
        <translation>Ungültige MAC-Adresse</translation>
    </message>
</context>
<context>
    <name>MulticastSetup</name>
    <message>
        <location filename="../multicastsetup.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../multicastsetup.ui" line="22"/>
        <source>IP Multicast Address</source>
        <translation>IP-Multicast-Adresse</translation>
    </message>
    <message>
        <location filename="../multicastsetup.ui" line="29"/>
        <source>Join</source>
        <translation>Beitreten</translation>
    </message>
    <message>
        <location filename="../multicastsetup.ui" line="54"/>
        <source>Leave All Groups</source>
        <translation>Alle Gruppen verlassen</translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="15"/>
        <source>IPv4 Multicast Setup (Experimental)</source>
        <translation>IPv4-Multicast-Einrichtung (experimentell)</translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="31"/>
        <source>There are no bound UDP ports</source>
        <translation>Es gibt keine gebundenen UDP-Ports</translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="34"/>
        <source>UDP socket bound to </source>
        <translation>UDP Socket gebunden an</translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="36"/>
        <source> will join the multicast group</source>
        <translation> wird der Multicast-Gruppe beitreten</translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="59"/>
        <source>Not Multicast.</source>
        <translation>Nicht Multicast.</translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="63"/>
        <source>IP must be an IPv4 multicast address.
(224.0.0.0 to 239.255.255.255)</source>
        <translation>IP muss eine IPv4-Multicast-Adresse sein.
(224.0.0.0 bis 239.255.255.255)</translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="74"/>
        <source>IPv4-only.</source>
        <translation>Nur IPv4.</translation>
    </message>
    <message>
        <location filename="../multicastsetup.cpp" line="78"/>
        <source>Packet Sender supports multicast when binded to IPv4. 
Turn off IPv6 and switch to IPv4 mode?</source>
        <translation>Paket Sender unterstützt Multicast, wenn er an IPv4 gebunden ist.
Schalten Sie IPv6 aus und wechseln Sie in den IPv4-Modus?</translation>
    </message>
</context>
<context>
    <name>PacketLogModel</name>
    <message>
        <location filename="../packetlogmodel.cpp" line="83"/>
        <source>Data portion is </source>
        <translation>Der Datenteil beträgt </translation>
    </message>
    <message>
        <location filename="../packetlogmodel.cpp" line="83"/>
        <source> bytes</source>
        <translation> bytes</translation>
    </message>
</context>
<context>
    <name>PacketNetwork</name>
    <message>
        <location filename="../packetnetwork.cpp" line="246"/>
        <source>Port bind error.</source>
        <translation>Portbindungsfehler.</translation>
    </message>
    <message>
        <location filename="../packetnetwork.cpp" line="250"/>
        <source>Packet Sender attempted (and failed) to bind to port [PORT], which is less than 1024. 

Privileged ports requires running Packet Sender with admin-level / root permissions.</source>
        <translation>Paket Sender hat versucht (und ist gescheitert), sich an Port [PORT] zu binden, der kleiner als 1024 ist.

Privilegierte Ports erfordern die Ausführung von Packet Sender mit Administrator-/Root-Berechtigungen.</translation>
    </message>
    <message>
        <location filename="../packetnetwork.cpp" line="251"/>
        <source>Packet Sender attempted (and failed) to bind to port [PORT].

 - Are you running multiple instances? 

 - Trying to bind to a missing custom IP?</source>
        <translation>Paket Sender hat versucht (und ist fehlgeschlagen), eine Bindung an Port [PORT] herzustellen.

- Betreiben Sie mehrere Instanzen?

- Versuchen Sie, sich an eine fehlende benutzerdefinierte IP zu binden?</translation>
    </message>
</context>
<context>
    <name>PanelGenerator</name>
    <message>
        <location filename="../panelgenerator.ui" line="20"/>
        <source>MainWindow</source>
        <translation>MainWindow</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="56"/>
        <location filename="../panelgenerator.ui" line="69"/>
        <location filename="../panelgenerator.ui" line="82"/>
        <location filename="../panelgenerator.ui" line="95"/>
        <location filename="../panelgenerator.ui" line="108"/>
        <location filename="../panelgenerator.ui" line="121"/>
        <location filename="../panelgenerator.ui" line="134"/>
        <location filename="../panelgenerator.ui" line="147"/>
        <location filename="../panelgenerator.ui" line="160"/>
        <source>PushButton</source>
        <translation>Drucktaste</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="183"/>
        <source>&amp;File</source>
        <translation>&amp;Datei</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="192"/>
        <source>&amp;Export</source>
        <translation>&amp;Exportieren</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="203"/>
        <source>&amp;Help</source>
        <translation>&amp;Hilfe</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="209"/>
        <source>S&amp;ettings</source>
        <translation>&amp;Einstellungen</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="223"/>
        <source>&amp;Save</source>
        <translation>&amp;Speichern</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="226"/>
        <source>Ctrl+S</source>
        <translation>Strg+S</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="231"/>
        <source>Save &amp;As...</source>
        <translation>Speichern &amp;als...</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="236"/>
        <source>&amp;Import Panels File</source>
        <translation>Panels-Datei importieren</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="239"/>
        <source>Ctrl+O</source>
        <translation>Strg+O</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="244"/>
        <source>Portable &amp;Windows Package</source>
        <translation>Tragbares &amp;Windows-Paket</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="247"/>
        <source>F5</source>
        <translation>F5</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="252"/>
        <source>&amp;Documentation</source>
        <translation>&amp;Dokumentation</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="255"/>
        <source>F1</source>
        <translation>F1</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="260"/>
        <source>Panel Name</source>
        <translation>Name des Panels</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="265"/>
        <source>Panel ID</source>
        <translation>Panel ID</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="273"/>
        <source>Starter Panel:</source>
        <translation>Anlasser Panel:</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="278"/>
        <location filename="../panelgenerator.cpp" line="48"/>
        <source>Delete Panel</source>
        <translation>Panel löschen</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="283"/>
        <source>&amp;Panels File</source>
        <translation>&amp;Panels Datei</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="288"/>
        <source>Portable &amp;macOS Package</source>
        <translation>Tragbares &amp;macOS-Paket</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="293"/>
        <source>Portable Linux Package</source>
        <translation>Tragbares Linux-Paket</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="298"/>
        <source>&amp;New Panel</source>
        <translation>&amp;Neues Panel</translation>
    </message>
    <message>
        <location filename="../panelgenerator.ui" line="301"/>
        <source>Ctrl+N</source>
        <translation>Strg+N</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="40"/>
        <source>Panels</source>
        <translation>Panels</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="47"/>
        <source>Load Panel</source>
        <translation>Panel laden</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="52"/>
        <location filename="../panelgenerator.cpp" line="364"/>
        <source>Viewing</source>
        <translation>Ansehen</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="135"/>
        <source>URL or File</source>
        <translation>URL oder Datei</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="136"/>
        <source>URL or File:</source>
        <translation>URL oder Datei:</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="155"/>
        <source>Link text</source>
        <translation>Text verlinken</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="156"/>
        <source>Link text:</source>
        <translation>Text verlinken:</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="321"/>
        <source>Confirm delete.</source>
        <translation>Bestätigen Sie das Löschen.</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="325"/>
        <source>Delete </source>
        <translation>Löschen </translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="331"/>
        <source>Deleting </source>
        <translation>Löschen </translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="339"/>
        <source>Panel </source>
        <translation>Panel </translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="341"/>
        <source>Set Panel Name: </source>
        <translation>Panel-Name festlegen:</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="342"/>
        <source>Set Panel ID: </source>
        <translation>Panel ID festlegen: </translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="346"/>
        <source>Packet Sender Panel: New Panel</source>
        <translation>Paket Sender Panel: Neues Panel</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="347"/>
        <source>Set Panel Name: New Panel</source>
        <translation>Panel Name festlegen: Neues Panel</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="348"/>
        <source>Set Panel ID: New Panel</source>
        <translation>Panel ID festlegen: Neues Panel</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="354"/>
        <source>Starter Panel: Yes</source>
        <translation>StarterPanel: Ja</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="356"/>
        <source>Starter Panel: No</source>
        <translation>StarterPanel: Nein</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="359"/>
        <source>Editing</source>
        <translation>Bearbeitung</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="436"/>
        <source>Button </source>
        <translation>Schaltfläche </translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="443"/>
        <source>(Button will be deleted)</source>
        <translation>(Die Schaltfläche wird gelöscht)</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="453"/>
        <source>Test</source>
        <translation>Testen</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="460"/>
        <source>Script is empty</source>
        <translation>Das Skript ist leer</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="522"/>
        <location filename="../panelgenerator.cpp" line="527"/>
        <source>New Button</source>
        <translation>Neue Schaltfläche</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="692"/>
        <source>Nothing to do...</source>
        <translation>Nichts zu tun...</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="694"/>
        <source>Executing </source>
        <translation>Ausführen </translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="699"/>
        <source>Unknown Command</source>
        <translation>Unbekannter Befehl</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="769"/>
        <source>Transition Panel</source>
        <translation>Übergang zu Panel</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="773"/>
        <source>Tranisition to Panel &quot;</source>
        <translation>Übergang zu Panel &quot;</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="773"/>
        <source>&quot;?
This panel has not been saved. You may lose changes.</source>
        <translation>&quot;?
Dieses Panel wurde noch nicht gespeichert. Sie können Änderungen verlieren.</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="785"/>
        <source>Not loading panel</source>
        <translation>Panel wird nicht geladen</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="789"/>
        <source>Not loading panel in edit mode</source>
        <translation>Das Panel wird im Bearbeitungsmodus nicht geladen</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="905"/>
        <source>Change URL</source>
        <translation>URL ändern</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="906"/>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="913"/>
        <source>Delete link</source>
        <translation>Link löschen</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="917"/>
        <source>Delete URL link?
</source>
        <translation>URL-Link löschen?</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="928"/>
        <source>Change Text</source>
        <translation>Text ändern</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="929"/>
        <source>text:</source>
        <translation>Text:</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="990"/>
        <source>Panels File</source>
        <translation>Panels Datei</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="992"/>
        <source>*.panels</source>
        <translation>*.panels</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1029"/>
        <source>Unknown File</source>
        <translation>Unbekannte Datei</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1032"/>
        <source>This does not seem to be a valid PS Panels file</source>
        <translation>Dies scheint keine gültige PS Panels-Datei zu sein</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1046"/>
        <location filename="../panelgenerator.cpp" line="1071"/>
        <source>Found </source>
        <translation>Gefunden </translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1046"/>
        <source> packets. Saving overwrites duplicate names.

Continue packet import?</source>
        <translation> pakete. Beim Speichern werden doppelte Namen überschrieben.

Import von Paketen fortsetzen?</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1071"/>
        <source> panels. Ovewrite dpulicated IDs?

Selecting No will generate new IDs and append.</source>
        <translation> doppelte. IDs überschreiben?

Wenn Sie Nein wählen, werden neue IDs erzeugt und angehängt.</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1143"/>
        <source>Coming soon.</source>
        <translation>Kommt bald</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1160"/>
        <source>Change Name</source>
        <translation>Name ändern</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1161"/>
        <location filename="../panelgenerator.cpp" line="1209"/>
        <source>Name:</source>
        <translation>Name:</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1177"/>
        <source>Change ID</source>
        <translation>ID ändern</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1178"/>
        <source>ID:</source>
        <translation>ID:</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1208"/>
        <source>New Name</source>
        <translation>Neuer Name</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1243"/>
        <source>Save PS Panels</source>
        <translation>PS-Panels speichern</translation>
    </message>
    <message>
        <location filename="../panelgenerator.cpp" line="1244"/>
        <source>panels (*.panels)</source>
        <translation>panels (*.panels)</translation>
    </message>
</context>
<context>
    <name>PersistentConnection</name>
    <message>
        <location filename="../persistentconnection.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="26"/>
        <source>Waiting...</source>
        <translation>Warte... </translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="40"/>
        <source>Load</source>
        <translation>Laden</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="47"/>
        <source>Search Packets...</source>
        <translation>Pakete suchen...</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="61"/>
        <source>Raw</source>
        <translation>Rohe</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="71"/>
        <source>ASCII</source>
        <translation>ASCII</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="84"/>
        <source>ASCII. Press Enter to Send.</source>
        <translation>ASCII. Drücken Sie Enter zum Senden.</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="94"/>
        <source>Send</source>
        <translation>Senden</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="104"/>
        <source>Append \r</source>
        <translation>Anhängen \r</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="114"/>
        <location filename="../persistentconnection.cpp" line="468"/>
        <source>Send File</source>
        <translation>Datei senden</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="158"/>
        <source>Clear Log</source>
        <translation>Log löschen</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="165"/>
        <source>To Clipboard</source>
        <translation>In die Zwischenablage</translation>
    </message>
    <message>
        <location filename="../persistentconnection.ui" line="185"/>
        <source>Resending(1)</source>
        <translation>Erneut senden (1)</translation>
    </message>
    <message>
        <location filename="../persistentconnection.cpp" line="154"/>
        <location filename="../persistentconnection.cpp" line="156"/>
        <source>You:</source>
        <translation>Du:</translation>
    </message>
    <message>
        <location filename="../persistentconnection.cpp" line="470"/>
        <source>*.*</source>
        <translation>*.*</translation>
    </message>
    <message>
        <location filename="../persistentconnection.cpp" line="511"/>
        <source>Copied</source>
        <translation>Kopiert</translation>
    </message>
    <message>
        <location filename="../persistentconnection.cpp" line="512"/>
        <source>Output sent to your clipboard</source>
        <translation>Ausgabe in Ihre Zwischenablage</translation>
    </message>
</context>
<context>
    <name>PersistentHTTP</name>
    <message>
        <location filename="../persistenthttp.ui" line="26"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../persistenthttp.ui" line="44"/>
        <source>Copy Code</source>
        <translation>Kode kopieren</translation>
    </message>
    <message>
        <location filename="../persistenthttp.ui" line="64"/>
        <source>.html View/Edit</source>
        <translation>.html Anzeigen/Bearbeiten</translation>
    </message>
</context>
<context>
    <name>PostDataGen</name>
    <message>
        <location filename="../postdatagen.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../postdatagen.ui" line="22"/>
        <source>Key</source>
        <translation>Schlüssel</translation>
    </message>
    <message>
        <location filename="../postdatagen.ui" line="32"/>
        <source>Value</source>
        <translation>Wert</translation>
    </message>
    <message>
        <location filename="../postdatagen.ui" line="42"/>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <location filename="../postdatagen.ui" line="51"/>
        <source>Params</source>
        <translation>Params</translation>
    </message>
    <message>
        <location filename="../postdatagen.cpp" line="30"/>
        <source>Data Generator</source>
        <translation>Datengenerator</translation>
    </message>
</context>
<context>
    <name>PreviewFilter</name>
    <message>
        <location filename="../mainwindow.cpp" line="2726"/>
        <source>Multi-line editor</source>
        <translation>Mehrzeiliger Editor</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2732"/>
        <source>Update</source>
        <translation>Aktualisierung</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2733"/>
        <source>Close</source>
        <translation>Schliessen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../packet.cpp" line="266"/>
        <location filename="../settings.cpp" line="44"/>
        <source>Send</source>
        <translation>Senden</translation>
    </message>
    <message>
        <location filename="../packet.cpp" line="267"/>
        <source>Send &lt;b&gt;</source>
        <translation>Senden &lt;b&gt;</translation>
    </message>
    <message>
        <location filename="../packet.cpp" line="627"/>
        <source>Received an invalid MAC address</source>
        <translation>Es wurde eine ungültige MAC-Adresse empfangen</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="47"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="50"/>
        <source>Resend</source>
        <translation>Erneut senden</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="53"/>
        <source>To Address</source>
        <translation>Zur Adresse</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="56"/>
        <source>To Port</source>
        <translation>Zum Port</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="59"/>
        <source>Method</source>
        <translation>Methode</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="62"/>
        <source>Request Path</source>
        <translation>Pfad der Anfrage</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="65"/>
        <source>Time</source>
        <translation>Zeit</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="68"/>
        <source>From IP</source>
        <translation>Von IP</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="71"/>
        <source>From Port</source>
        <translation>Von Port</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="74"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="24"/>
        <source>Network</source>
        <translation>Netzwerk</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="30"/>
        <source>Basic</source>
        <translation>Grundlegend</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="36"/>
        <source>Enable UDP Servers</source>
        <translation>UDP Server aktivieren</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="45"/>
        <source>UDP Server Ports (comma-separated, 0 for random)</source>
        <translation>UDP Server ports (durch Kommas getrennt, 0 für zufällig)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="52"/>
        <location filename="../settings.ui" line="77"/>
        <location filename="../settings.ui" line="102"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="61"/>
        <source>Enable TCP Servers</source>
        <translation>TCP-Server aktivieren</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="70"/>
        <source>TCP Server Port (comma-separated, 0 for random)</source>
        <translation>TCP Server ports (durch Kommas getrennt, 0 für zufällig)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="86"/>
        <source>Enable SSL/TLS Servers</source>
        <translation>SSL/TLS Server aktivieren</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="95"/>
        <source>SSL Server Port (comma-separated, 0 for random)</source>
        <translation>SSL Server ports (durch Kommas getrennt, 0 für zufällig)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="111"/>
        <source>Set the server ports to 0 if you want to run multiple Packet Sender instances.</source>
        <translation>Setzen Sie die Server-Ports auf 0, wenn Sie mehrere Paketsender Instanzen ausführen möchten.</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="125"/>
        <source>Translate macros when sending</source>
        <translation>Übersetzen Sie Makros beim Senden</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="132"/>
        <source>Send a basic response with macro support</source>
        <translation>Senden einer einfachen Antwort mit Makrounterstützung</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="141"/>
        <source>Response Data</source>
        <translation>Antwort Daten</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="155"/>
        <source>ASCII</source>
        <translation>ASCII</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="169"/>
        <location filename="../settings.ui" line="771"/>
        <location filename="../settings.ui" line="833"/>
        <location filename="../settings.ui" line="867"/>
        <location filename="../settings.ui" line="908"/>
        <location filename="../settings.ui" line="941"/>
        <source>HEX</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settings.ui" line="197"/>
        <source>Additional UDP/TCP/SSL Settings</source>
        <translation>Zusätzliche UDP/TCP/SSL-Einstellungen</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="205"/>
        <source>IPv4 Only</source>
        <translation>Nur IPv4</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="218"/>
        <source>IPv6 Only</source>
        <translation>Nur IPv6</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="230"/>
        <source>Bind This:</source>
        <translation>Binden das:</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="240"/>
        <source>Your IP</source>
        <translation>Deine IP</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="253"/>
        <source>Multi-Send Delay (sec)</source>
        <translation>Verzögerung bei mehreren Sendungen (Sek)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="260"/>
        <source>0.0 for off</source>
        <translation>0,0 für aus</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="271"/>
        <source>Cancel Resending after # packets</source>
        <translation>Abbrechen Erneutes Senden nach # Paketen</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="278"/>
        <source>0 for off</source>
        <translation>0 für aus</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="287"/>
        <source>Attempt Receive Before Send</source>
        <translation>Versuchen Sie, vor dem Senden zu empfangen</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="294"/>
        <source>500 ms delay after connect (slow devices)</source>
        <translation>500 ms Verzögerung nach der Verbindung (langsame Geräte)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="301"/>
        <source>Persistent TCP Connections</source>
        <translation>Persistente TCP-Verbindungen</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="308"/>
        <source>Resolve DNS during input (old method)</source>
        <translation>DNS bei der Eingabe auflösen (alte Methode)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="315"/>
        <source>Ignore SSL Errors (Wrong host, expired, self-signed, etc)</source>
        <translation>SSL-Fehler ignorieren (Falscher Host, abgelaufen, selbstsigniert usw.)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="328"/>
        <source>SSL Server may use an internal snake oil cert</source>
        <translation>Der SSL-Server verwendet möglicherweise ein internes Snake-Oil-Zertifika</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="337"/>
        <source>SSL CA Certificates</source>
        <translation>SSL CA-Zertifikate</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="344"/>
        <source>Path from where to load the CA certificats (leave empty for defaults)</source>
        <translation>Pfad, von dem aus die CA-Zertifikate geladen werden sollen (für Standardeinstellungen leer lassen)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="351"/>
        <location filename="../settings.ui" line="376"/>
        <location filename="../settings.ui" line="401"/>
        <source>Browse</source>
        <translation>Stöbern</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="362"/>
        <source>SSL Local Certificate</source>
        <translation>&gt;Lokales SSL-Zertifikat</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="369"/>
        <source>File path for the client side local certificate</source>
        <translation>Dateipfad für das clientseitige lokale Zertifikat</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="387"/>
        <source>SSL Private Key</source>
        <translation>Privater SSL-Schlüssel</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="394"/>
        <source>File path for the client side private key</source>
        <translation>Dateipfad für den clientseitigen privaten Schlüssel</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="430"/>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="436"/>
        <source>Automatically adjust ContentType when sending XML or JSON</source>
        <translation>Passen Sie ContentType automatisch an, wenn Sie XML oder JSON senden</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="458"/>
        <source>Generate Auth Header</source>
        <translation>Automatische Kopfzeile generieren</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="469"/>
        <location filename="../settings.cpp" line="975"/>
        <source>Host</source>
        <translation>Gastgeber</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="479"/>
        <source>Username/ClientID</source>
        <translation>Benutzername/Kunden-ID</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="489"/>
        <source>Password/AccessCode</source>
        <translation>Passwort/Zugangscode</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="499"/>
        <location filename="../settings.cpp" line="1046"/>
        <source>HTTP Header</source>
        <translation>HTTP-Kopfzeile</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="530"/>
        <source>Delete Header</source>
        <translation>Kopfzeile löschen</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="540"/>
        <source>Display</source>
        <translation>Anzeige</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="548"/>
        <source>Saved Packet Display Order (Drag and Drop)</source>
        <translation>Reihenfolge der Anzeige gespeicherter Pakete (Ziehen und Ablegen)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="555"/>
        <location filename="../settings.ui" line="583"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="560"/>
        <location filename="../settings.ui" line="588"/>
        <source>To IP</source>
        <translation>Zu IP</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="565"/>
        <location filename="../settings.ui" line="593"/>
        <source>From IP</source>
        <translation>Von IP</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="576"/>
        <source>Traffic Log Display Order (Drag and Drop)</source>
        <translation>Reihenfolge der Anzeige des Verkehrslogs (Ziehen und Ablegen)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="601"/>
        <source>Use Default Order</source>
        <translation>Standard Reihenfolge verwenden</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="626"/>
        <source>Miscellaneous</source>
        <translation>Sonstiges</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="632"/>
        <source>Use Dark Theme (requires restart)</source>
        <translation>Verwende Dark Theme (erfordert Neustart)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="641"/>
        <source>Language (Requires Restart)</source>
        <translation>Sprache (Neustart erforderlich)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="650"/>
        <source>Copy to Clipboard button uses raw data</source>
        <translation>Schaltfläche In Zwischenablage kopieren verwendet Rohdaten</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="657"/>
        <source>Rolling 100-entry traffic log</source>
        <translation>Rollendes Verkehrsprotokoll mit 100 Einträgen</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="664"/>
        <source>Restore previous session</source>
        <translation>Vorherige Sitzung wiederherstellen</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="671"/>
        <source>Periodically check for updates</source>
        <translation>Überprüfen Sie regelmäßig, ob Updates verfügbar sind</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="678"/>
        <source>Use ellipsis [...] for long data entries (helps performance)</source>
        <translation>Verwenden Sie die Ellipse [...] für lange Dateneingaben (verbessert die Leistung)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="685"/>
        <source>Auto-Launch Starter Panel</source>
        <translation>Starterpanel für den automatischen Start</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="722"/>
        <source>Smart Responses</source>
        <translation>Intelligente Antworten</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="730"/>
        <source>Send a Smart Response with Macro Support</source>
        <translation>Senden Sie eine intelligente Antwort mit Makrounterstützung</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="758"/>
        <source>Response 5</source>
        <translation>Antwort 5</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="766"/>
        <location filename="../settings.ui" line="828"/>
        <location filename="../settings.ui" line="862"/>
        <location filename="../settings.ui" line="903"/>
        <location filename="../settings.ui" line="936"/>
        <source>Mixed ASCII</source>
        <translation>Gemischter ASCII</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="779"/>
        <location filename="../settings.ui" line="844"/>
        <location filename="../settings.ui" line="882"/>
        <location filename="../settings.ui" line="895"/>
        <location filename="../settings.ui" line="928"/>
        <source>Enable</source>
        <translation>Aktiviere</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="786"/>
        <source>Response 4</source>
        <translation>Antwort 4</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="793"/>
        <source>If Packet data equals</source>
        <translation>Wenn Paketdaten gleich</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="800"/>
        <source>Reply with</source>
        <translation>Antwort mit</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="807"/>
        <source>Encoding</source>
        <translation>Kodierung</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="814"/>
        <source>Response 1</source>
        <translation>Antwort 1</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="854"/>
        <source>Response 2</source>
        <translation>Antwort 2</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="875"/>
        <source>Response 3</source>
        <translation>Antwort 3</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="963"/>
        <source>Available macros: {{DATE}} {{TIME}} {{RANDOM}} {{UNIXTIME}} {{UNIQUE}}</source>
        <translation>Verfügbare Makros: {{DATE}} {{TIME}} {{RANDOM}} {{UNIXTIME}} {{UNIQUE}</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="970"/>
        <source>Packet Sender will swap macro with a real value before sending</source>
        <translation>Der Paketsender tauscht das Makro vor dem Senden mit einem echten Wert aus</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="981"/>
        <source>{{DATE}} format (Requires Restart)</source>
        <translation>{{DATE}} format (Neustart erforderlich)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="998"/>
        <location filename="../settings.ui" line="1039"/>
        <source>Example</source>
        <translation>Beispiel</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="1022"/>
        <source>{{TIME}} format (Requires Restart)</source>
        <translation>{{TIME}} format (Neustart erforderlich)</translation>
    </message>
    <message>
        <location filename="../settings.ui" line="1083"/>
        <source>Online Documentation</source>
        <translation>Online Dokumentation</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="103"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="359"/>
        <source>Bad IP.</source>
        <translation>Schlechte IP.</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="363"/>
        <source>Packet Sender cannot bind invalid IP </source>
        <translation>Paketabsender kann ungültige IP nicht binden</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="377"/>
        <source>TCP and SSL non-zero port conflict.</source>
        <translation>TCP- und SSL-Portkonflikt ungleich Null.</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="381"/>
        <source>Packet Sender cannot bind TCP and SSL to the same port.</source>
        <translation>Paketsender kann TCP und SSL nicht an denselben Port binden.</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="726"/>
        <source>Open Directory</source>
        <translation>Verzeichnis öffnen</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="747"/>
        <source>Choose Cert</source>
        <translation>Zertifikat wählen</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="747"/>
        <source>Certs (*.pem)</source>
        <translation>Zertifikate (*.pem)</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="763"/>
        <source>Choose Key</source>
        <translation>Schlüssel wählen</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="763"/>
        <source>Keys (*.key, *.pem)</source>
        <translation>Schlüssel (*.key, *.pem)</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="975"/>
        <location filename="../settings.cpp" line="1044"/>
        <source>Key</source>
        <translation>Schlüssel</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="975"/>
        <location filename="../settings.cpp" line="1045"/>
        <source>Value</source>
        <translation>Wert</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="1040"/>
        <source>UN/ClientID</source>
        <translation>UN/KundenID</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="1041"/>
        <source>PW/Access</source>
        <translation>PW/Zugang</translation>
    </message>
    <message>
        <location filename="../settings.cpp" line="1042"/>
        <source>HTTP Auth Header</source>
        <translation>HTTP Authentifizierungsheader</translation>
    </message>
</context>
<context>
    <name>SubnetCalc</name>
    <message>
        <location filename="../subnetcalc.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="26"/>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="33"/>
        <source>IPv4 address</source>
        <translation>IPv4 Adresse</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="44"/>
        <source>Subnet</source>
        <translation>Subnetz</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="51"/>
        <source>Dotted or number of bits </source>
        <translation>Punktiert oder Anzahl der Bits </translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="66"/>
        <source>Start</source>
        <translation>Beginne</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="76"/>
        <source>Calculated Start..</source>
        <translation>Berechneter Start..</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="87"/>
        <source>End</source>
        <translation>Ende</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="97"/>
        <source>Calculated End...</source>
        <translation>Berechnetes Ende...</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="108"/>
        <source>Broadcast</source>
        <translation>Übertragung</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="118"/>
        <source>Broadcast...</source>
        <translation>Übertragung...</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="133"/>
        <source>Within subnet check</source>
        <translation>Innerhalb des Subnetzes überprüfen</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="140"/>
        <source>IP Address...</source>
        <translation>IP Adresse...</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="156"/>
        <source>Subnet Check Result...</source>
        <translation>Ergebnis der Subnetzprüfung...</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="168"/>
        <source>Results log...</source>
        <translation>Ergebnis Log...</translation>
    </message>
    <message>
        <location filename="../subnetcalc.ui" line="177"/>
        <source>Clear</source>
        <translation>Klar</translation>
    </message>
    <message>
        <location filename="../subnetcalc.cpp" line="24"/>
        <source>IPv4 Subnet Calculator</source>
        <translation>IPv4-Subnetz-Rechner</translation>
    </message>
    <message>
        <location filename="../subnetcalc.cpp" line="26"/>
        <source>Your non-loopback addresses: 

</source>
        <translation>Ihre Nicht-Loopback-Adressen:

</translation>
    </message>
    <message>
        <location filename="../subnetcalc.cpp" line="263"/>
        <source>Within </source>
        <translation>Innerhalb </translation>
    </message>
    <message>
        <location filename="../subnetcalc.cpp" line="273"/>
        <source>No entries in subnet.</source>
        <translation>Keine Einträge im Subnetz.</translation>
    </message>
</context>
<context>
    <name>UDPFlooding</name>
    <message>
        <location filename="../udpflooding.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="24"/>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="38"/>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="54"/>
        <source>Ascii</source>
        <translation>Ascii</translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="76"/>
        <source>Delay (ms)</source>
        <translation>Verzögerung (ms)</translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="86"/>
        <source>Speed (MB/s)</source>
        <translation>Geschwindigkeit (MB/s)</translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="101"/>
        <source>0 or blank is no delay or max speed</source>
        <translation>0 oder leer ist keine Verspätung oder Höchstgeschwindigkeit</translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="110"/>
        <source>Start</source>
        <translation>Beginne</translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="117"/>
        <source>Stop</source>
        <translation>Stopp</translation>
    </message>
    <message>
        <location filename="../udpflooding.ui" line="139"/>
        <source>Waiting to send...</source>
        <translation>Ich warte darauf, sie zu senden...</translation>
    </message>
    <message>
        <location filename="../udpflooding.cpp" line="25"/>
        <source>UDP Traffic Generator (Experimental)</source>
        <translation>UDP Verkehrsgenerator (experimentell)</translation>
    </message>
    <message>
        <location filename="../udpflooding.cpp" line="76"/>
        <location filename="../udpflooding.cpp" line="81"/>
        <source>Invalid</source>
        <translation>Ungültig</translation>
    </message>
</context>
<context>
    <name>WakeOnLAN</name>
    <message>
        <location filename="../wakeonlan.ui" line="14"/>
        <source>Wake-On-LAN</source>
        <translation>Wake-On-LAN</translation>
    </message>
    <message>
        <location filename="../wakeonlan.ui" line="22"/>
        <source>Target MAC</source>
        <translation>Ziel-MAC</translation>
    </message>
    <message>
        <location filename="../wakeonlan.ui" line="29"/>
        <source>01:23:45:67:89:ab</source>
        <translation>01:23:45:67:89:ab</translation>
    </message>
    <message>
        <location filename="../wakeonlan.ui" line="36"/>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <location filename="../wakeonlan.ui" line="59"/>
        <source>7</source>
        <translation>7</translation>
    </message>
    <message>
        <location filename="../wakeonlan.ui" line="68"/>
        <source>9</source>
        <translation>9</translation>
    </message>
</context>
</TS>
